%define current_version 3.0.91
%define cur_release 1

%define _source_payload w7.gzdio
%define _binary_payload w7.gzdio
%define _source_filedigest_algorithm  1
%define _binary_filedigest_algorithm  1

%define vz_suffix -vz
%define app_name qemu-ga
%define bin_name qemu-ga

%global pkgsuffix %{vz_suffix}
%global obsoletes_version 15:0-0

%define semodules_dir %{_datadir}/selinux/packages

# Macro to properly setup conflict handling
%define vz_obsoletes() \
Provides: %1 = %{version}-%{release} \
Obsoletes: %1 < %{obsoletes_version}

Summary: QEMU guest agent
Name: qemu-guest-agent%{?pkgsuffix}
Version: %{current_version}
Release: %{cur_release}.el6
License: GPLv2+ and LGPLv2+ and BSD
Group: System Environment/Daemons
Group: Development/Tools
URL: http://www.qemu.org/
%vz_obsoletes qemu-guest-agent

Source0: http://wiki.qemu.org/download/qemu-%{version}.tar.bz2
%define glib glib-2.40.2
Source1: %{glib}.tar.xz
Patch1: qemu-glibc-configure.patch

Source10: qemu-guest-agent.init
Source13: %{bin_name}.sysconfig
Source14: virt_vz.te
Source15: virt_vz.pp_6_6

BuildRequires: zlib-static
BuildRequires: glibc-static
BuildRequires: glib2-static
BuildRequires: SDL-devel
BuildRequires: which
BuildRequires: texi2html
BuildRequires: gnutls-devel
BuildRequires: cyrus-sasl-devel
BuildRequires: libtool
BuildRequires: libaio-devel
BuildRequires: rsync
BuildRequires: python
BuildRequires: pciutils-devel
BuildRequires: pulseaudio-libs-devel
BuildRequires: ncurses-devel
BuildRequires: libattr-devel
BuildRequires: pixman-devel
BuildRequires: selinux-policy-devel
BuildRequires: libffi-devel

%description
qemu-kvm is an open source virtualizer that provides hardware emulation for
the KVM hypervisor. 

This package provides an agent to run inside guests, which communicates
with the host over a virtio-serial channel named "org.qemu.guest_agent.0"

This package does not need to be installed on the host OS.

%prep
%setup -q -n qemu-%{version}
%patch1 -p 1
%setup -q -T -D -b 1 -n %{glib}

%build
mkdir -p root
glib_install_dir=%{_builddir}/%{glib}/root
./configure --enable-static --disable-shared --prefix=$glib_install_dir
make %{?_smp_mflags}
make install
export GLIB_ROOT_DIR=$glib_install_dir

cd ../qemu-%{version}

./configure \
        --prefix=%{_prefix} \
        --with-confsuffix=/%{app_name} \
        --libdir=%{_libdir} \
        --docdir=%{_docdir}/%{app_name} \
        --sysconfdir=%{_sysconfdir} \
        --localstatedir=%{_localstatedir} \
        --libexecdir=%{_libexecdir} \
        --with-pkgversion=%{name}-%{version}-%{release} \
        --target-list= --cpu=%{_arch} \
        --disable-fdt \
        --enable-guest-agent \
        --disable-pie

# -Werror due to static linkage
make %{bin_name} %{?_smp_mflags} -Werror

# selinux stuff
install -m 644 %SOURCE14 $RPM_BUILD_DIR/qemu-%{version}

make -f /usr/share/selinux/devel/Makefile virt_vz.pp

%install
cd ../qemu-%{version}

# For the qemu-guest-agent subpackage, install:
# - the SysV init script and the udev rules:
install -D -p -m 0755 %{SOURCE10} $RPM_BUILD_ROOT%{_initddir}/qemu-guest-agent

# - the environment file for the SysV init script:
install -D -p -m 0644 %{SOURCE13} \
  $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/%{app_name}

# - the fsfreeze hook script:
install -D --preserve-timestamps \
  scripts/qemu-guest-agent/fsfreeze-hook \
  $RPM_BUILD_ROOT%{_sysconfdir}/%{app_name}/fsfreeze-hook

# - the directory for user scripts:
mkdir $RPM_BUILD_ROOT%{_sysconfdir}/%{app_name}/fsfreeze-hook.d

# - and the fsfreeze script samples:
mkdir --parents $RPM_BUILD_ROOT%{_datadir}/%{app_name}/fsfreeze-hook.d/
install --preserve-timestamps --mode=0644 \
  scripts/qemu-guest-agent/fsfreeze-hook.d/*.sample \
  $RPM_BUILD_ROOT%{_datadir}/%{app_name}/fsfreeze-hook.d/

# - Install dedicated log directory:
mkdir -p -v $RPM_BUILD_ROOT%{_localstatedir}/log/%{app_name}/

mkdir -p $RPM_BUILD_ROOT%{_bindir}
install -c -m 0755  %{bin_name} ${RPM_BUILD_ROOT}%{_bindir}/%{bin_name}

# Selinux stuff
mkdir -p ${RPM_BUILD_ROOT}%semodules_dir
install -m 644 virt_vz.pp ${RPM_BUILD_ROOT}%semodules_dir
install -m 644 %{SOURCE15} ${RPM_BUILD_ROOT}%semodules_dir

# Documentation
mkdir -p ${RPM_BUILD_ROOT}%{_docdir}/%{app_name}
install -m 644 COPYING README ${RPM_BUILD_ROOT}%{_docdir}/%{app_name}/
touch ${RPM_BUILD_ROOT}%{_datadir}/%{app_name}/VERSION

%post
# Always enable
/sbin/chkconfig --add qemu-guest-agent
/sbin/chkconfig qemu-guest-agent on

# Selinux
cat /etc/centos-release 2>/dev/null | grep '6.6' > /dev/null 2>&1
[ $? -eq 0 ] && module=virt_vz.pp_6_6 || module=virt_vz.pp
%{_sbindir}/semodule -n -s targeted -i %semodules_dir/$module > /dev/null 2>&1
if %{_sbindir}/selinuxenabled ; then
	%{_sbindir}/load_policy > /dev/null 2>&1
fi

# Workaround for chpasswd selinux domain
chcon -t passwd_exec_t /usr/sbin/chpasswd > /dev/null 2>&1

# Always start
/sbin/service qemu-guest-agent start >/dev/null 2>&1
:

%preun
if [ $1 -eq 0 ]; then
    /sbin/service qemu-guest-agent stop &>/dev/null || :
    /sbin/chkconfig --del qemu-guest-agent
fi

%postun
if [ $1 -ge 1 ]; then
	/sbin/service qemu-guest-agent condrestart >/dev/null 2>&1 || :
fi

%files
%defattr(-,root,root,-)
%doc %{_docdir}/%{app_name}/COPYING
%doc %{_docdir}/%{app_name}/README
%ghost %{_datadir}/%{app_name}/VERSION
%{_bindir}/%{bin_name}
%{_initddir}/qemu-guest-agent
%{_sysconfdir}/sysconfig/%{app_name}
%{_sysconfdir}/%{app_name}
%{_datadir}/%{app_name}
%dir %{_localstatedir}/log/%{app_name}
%semodules_dir

%changelog
* Tue Mar 26 2019 Yuriy Pudgorodskiy <yur@virtuozzo.com> 3.0.91-1
- Merge branch 'master' from 3.0.91 into vz7-rtm for vz7-upd10 #PSBM-91807

* Tue Dec 11 2018 Yuriy Pudgorodskiy <yur@virtuozzo.com> 2.9.90-7
- Fixed segfault use after in i/o watch callbacks #PSBM-89882

* Wed Oct 24 2018 Yuriy Pudgorodskiy <yur@virtuozzo.com> 2.9.90-5
- Skip already freezed fs #PSBM-82512

* Tue Oct 16 2018 Konstantin Volkov <wolf@virtuozzo.com> 2.9.90-4
- Added binary 6.6 virt_vz selinux module for compatibility, see #VSTOR-16117

* Wed Jun 27 2018 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 2.9.90-3
- Switched to ALT Linux compatible gzip payload compression, #ROSP-225

* Tue Aug 29 2017 Konstantin Volkov <wolf@virtuozzo.com> 2.9.90-2
- Updated qga to v2.9.90

* Fri Jan 20 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> - 2.5.50-1
- Support VERSION file for overriding reported GA version, #PSBM-56747
- Synchronized package version with source version

* Wed Aug 17 2016 Konstantin Volkov <wolf@virtuozzo.com> - 2.5.0-22
- Ignore EBUSY for fsfreeze call #PSBM-50465

* Wed Aug 17 2016 Konstantin Volkov <wolf@virtuozzo.com> - 2.5.0-21
- Dont return error if cant parse slave virtual device link - #PSBM-43139
- Return statvfs() fsinfo on posix - #PSBM-43139

* Fri May 27 2016 Konstantin Volkov <wolf@virtuozzo.com> - 2.5.0-20
- Moved VSS registration out of installer scope into agent #PSBM-47558

* Mon May 23 2016 Konstantin Volkov <wolf@virtuozzo.com> - 2.5.0-19
- Implemented guest-exec-terminate #PSBM-45383
- Added win32 event logging to qemu-ga.exe
- Translate glib log levels to system levels (syslog or windows event)
- Added custom syslog level mask

* Wed Mar 30 2016 Konstantin Volkov <wolf@virtuozzo.com> - 2.5.0-18
- Fixed a number of errors triggered by guest process termination before
  all stdin data sinked, #PSBM-45094
- generic code cleanup and small bugfixes. For #PSBM-43913 and #PSBM-44768

* Fri Mar  4 2016 Konstantin Volkov <wolf@virtuozzo.com> - 2.5.0-17
- Fixed dup message from  bad code in flush of aux channel, see #PSBM-44768

* Wed Feb 17 2016 Konstantin Volkov <wolf@virtuozzo.com> - 2.5.0-16
- Updated Linux guest exec shell quoting rules - #PSBM-44045

* Tue Feb  9 2016 Konstantin Volkov <wolf@virtuozzo.com> - 2.5.0-14
- Fixed memleak of aux output channels used with sync write codepath.
  Issue #PSBM-43996

* Sat Feb  6 2016 Konstantin Volkov <wolf@virtuozzo.com> - 2.5.0-13
- Preliminary support for interactive shell. For #PSBM-40821

* Thu Feb  4 2016 Konstantin Volkov <wolf@virtuozzo.com> - 2.5.0-12
- Fixed default aux channel path not set if main channel path was
  specificed from command line, see #PSBM-40821

* Wed Feb  3 2016 Konstantin Volkov <wolf@virtuozzo.com> - 2.5.0-11
- Seekable chr dev glib workaround, see #PSBM-40821

* Wed Dec 30 2015 Konstantin Volkov <wolf@virtuozzo.com> - 2.5.0-10
- Quote shell args for execute-in-shell on linux (#PSBM-42726)

* Wed Dec 23 2015 Konstantin Volkov <wolf@odin.com> - 2.5.0-9
- Renamed qga service, see #PSBM-42627

* Mon Dec  7 2015 Konstantin Volkov <wolf@odin.com> - 2.5.0-8
- Limited guest-exec stdout/stderr data to maximum supported by
  libvirt xdr rpc for #PSBM-42041

* Fri Dec  4 2015 Konstantin Volkov <wolf@odin.com> - 2.5.0-7
- guest-set-user-password - added ability to create new user

* Tue Dec  1 2015 Konstantin Volkov <wolf@odin.com> - 2.5.0-6
- Added guest-exec - new 'execute-in-shell' option

* Thu Nov 26 2015 Konstantin Volkov <wolf@odin.com> - 2.5.0-5
- Set permissive domain, see #PSBM-41596

* Fri Nov 20 2015 Konstantin Volkov <wolf@odin.com> - 2.5.0-4
- Added prl_nettool selinux support

* Thu Nov 19 2015 Konstantin Volkov <wolf@odin.com> - 2.5.0-3
- Added selinux support

* Mon Nov 16 2015 Konstantin Volkov <wolf@odin.com> - 2.5.0-1
- Initial release for el6
