%define instdir /usr/share/vz-guest-tools

# Sources list
%define sources_lst() \
%((cd %_sourcedir;\
s=100;\
for f in *.rpm *deb *orig.tar.* *debian.tar.xz; do\
echo Source$s: $f;\
s=$((s+1))\
done))\
%nil

Summary: Virtuozzo Linux guest tools
Name: vz-guest-tools-lin
Group: System Environment/Base
License: GPLv2
Source1: 90-guest_iso.rules
Source2: install
Source3: install-tools
Source4: prl_backup
# Statically linked fstrim from relatively modern util-linux
# for the old guests. We have to build it in some old OS, not in Koji,
# to avoid dependency on new GLIBC* versions
Source5: util-linux-2.28.1.tar.gz
Source6: fstrim-2.28.1-static.gz
Version: 7.10
Release: 4%{?dist}
BuildArch: noarch
BuildRequires: genisoimage, coreutils

%sources_lst

%description
Package contains ISO image with necessary guest tools for Linux.

%build
rm -rf %{name}/iso
mkdir -p %{name}/iso
for script in %{SOURCE1} %{SOURCE2} %{SOURCE3} %{SOURCE4} %{SOURCE6}; do
	cp $script %{name}/iso
done
echo '%{version}-%{release}' >%{name}/iso/VERSION

mkdir %{name}/iso/dkms %{name}/iso/guest_pkgs

for f in %_sourcedir/*.x86_64.rpm %_sourcedir/*.noarch.rpm %_sourcedir/*.deb; do
	if [[ $f =~ "dkms" ]]; then
		cp $f %{name}/iso/dkms
	else
		cp $f %{name}/iso/guest_pkgs
	fi
done

genisoimage -graft-points -output %{name}.iso -volid vz-tools-lin -joliet -rock \
		/dkms/=%{name}/iso/dkms \
		/guest_pkgs/=%{name}/iso/guest_pkgs \
		%{name}/iso/fstrim* \
		%{name}/iso/install* \
		%{name}/iso/*rules \
		%{name}/iso/prl_backup \
		%{name}/iso/VERSION

%install
mkdir -p %{buildroot}/%{instdir}
mv %{name}.iso %{buildroot}/%{instdir}

INSTALL_TOOLS64=`cat %{SOURCE3} | base64 -w 0 2>/dev/null`

echo %{version}-%{release} > %{buildroot}/%{instdir}/%{name}.ver
cat > %{buildroot}/%{instdir}/vz-lin-user-config <<EOF
{
"write_files":[
{   "encoding": "b64",
    "content": "$INSTALL_TOOLS64",
    "owner": "root:root",
    "path": "/usr/bin/install-tools",
    "permissions": "0755"
}],
"runcmd": [
  [ "/usr/bin/install-tools" ],
  [ "/bin/bash", "-c",
    "for DEV in \$(blkid -olist | grep config-2 | awk '{ print \$1 }'); do eject \${DEV}; done"]
]
}
EOF


%clean
rm -rf %{buildroot}
rm -rf $RPM_BUILD_DIR/name

%files
%defattr(-,root,root,-)
%{instdir}/*.iso
%{instdir}/%{name}.ver
%{instdir}/vz-lin-user-config

%changelog
* Mon Apr  1 2019 Yuriy Pudgorodskiy <yur@virtuozzo.com> 7.10-4
- Merge branch 'master' json: Fix % handling when not interpolating

* Tue Mar 26 2019 Yuriy Pudgorodskiy <yur@virtuozzo.com> 7.10-3
- Merge branch 'master' from 3.0.91 into vz7-rtm for vz7-upd10 #PSBM-91807

* Mon Feb 18 2019 Yuriy Pudgorodskiy <yur@virtuozzo.com> 7.10-2
- Do not stop/start NM in case it has already been disabled #PSBM-91824

* Mon Feb 18 2019 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 7.10-1
- Changed version for the new branch.
- Added forced uninstallation of preinstalled qemu-guest-agent, #VSTOR-20481

* Thu Jan 10 2019 Konstantin Volkov <wolf@virtuozzo.com> 7.9-13
- Added debian9 and ubuntu16+ vz-guest-udev support, see #PSBM-89620

* Mon Dec 17 2018 Yuriy Pudgorodskiy <yur@virtuozzo.com> 7.9-12
- nm-set_dns.sh failed to work with multiple active interfaces #PSBM-90321

* Fri Dec 14 2018 Yuriy Pudgorodskiy <yur@virtuozzo.com> 7.9-11
- Added support for setting dns/hostname via NetworkManager #PSBM-90148

* Tue Dec 11 2018 Yuriy Pudgorodskiy <yur@virtuozzo.com> 7.9-10
- Fixed segfault use after in i/o watch callbacks #PSBM-89882

* Thu Nov 22 2018 Yuriy Pudgorodskiy <yur@virtuozzo.com> 7.9-8
- Support window size change for interactive shell of x-exec #PSBM-89956

* Wed Oct 24 2018 Yuriy Pudgorodskiy <yur@virtuozzo.com> 7.9-5
- Skip already freezed fs #PSBM-82512

* Wed Oct 24 2018 Denis Silakov <dsilakov@virtuozzo.com> 7.9-3
- Remove ifupdown installation, no longer needed, see #PSBM-89214

* Wed Oct 17 2018 Pavel Vokhmyanin <pvokhmyanin@virtuozzo.com> 7.9-2
- Handle ip4+ipv6 gateway configuration properly #PSBM-89352

* Tue Oct 16 2018 Konstantin Volkov <wolf@virtuozzo.com> 7.9-1
- Added binary 6.6 virt_vz selinux module for compatibility, see #VSTOR-16117

* Fri Oct  5 2018 Pavel Vokhmyanin <pvokhmyanin@virtuozzo.com> 7.8-12
- Exclude python from auto dependencies generator #PSBM-89235

* Wed Oct  3 2018 Pavel Vokhmyanin <pvokhmyanin@virtuozzo.com> 7.8-10
- Introduce netplan support for debian systems Ubuntu 17.10 #PSBM-87360

* Fri Jul 27 2018 Konstantin Volkov <wolf@virtuozzo.com> 7.8-8
- Interfaces cleanup must not depend on indentation #PSBM-87157

* Fri Jul 13 2018 Denis Silakov <dsilakov@virtuozzo.com> 7.8-7
- Added --offline option, see #PSBM-86581

* Wed Jul 11 2018 Denis Silakov <dsilakov@virtuozzo.com> 7.8-6
- Install ifupdown for Ubuntu 18.04 and higher, see #PSBM-86248

* Fri Jul  6 2018 Konstantin Volkov <wolf@virtuozzo.com> 7.8-5
- Added RedOS 7.x support, see #PSBM-86422

* Wed Jun 27 2018 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 7.8-4
- Added support for Alt Linux 8 without systemd, #ROSP-225

* Wed Apr 18 2018 Denis Silakov <dsilakov@virtuozzo.com> 7.8-3
- Rebuild with new init script for Deb- based guests, #PSBM-82404

* Tue Mar 13 2018 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 7.8-1
- Added tools version to the installation log, #PSBM-82343
- Version uplift to reflect Update 8

* Mon Mar  5 2018 Yuriy Pudgorodskiy <yur@virtuozzo.com> 7.7-4
- Depend qemu-ga agent on virtioser driver #PSBM-80872
- Fixed case when aux_remove_channel() was called without nulling aux chan ptr #PSBM-79899

* Thu Feb  8 2018 Pavel Vokhmyanin <pvokhmyanin@virtuozzo.com> 7.7-4
- Store tools version in a file #PSBM-81320

* Wed Dec 20 2017 Yuriy Pudgorodskiy <yur@virtuozzo.com> 7.7-3
- Modified debian scripts to use generic nm-scripts  #PSBM-78056

* Wed Nov  8 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 7.6-15
- Adapted workaround for read-only root in Debian/Ubuntu, now for background, #PSBM-76920

* Tue Nov  7 2017 Yuriy Pudgorodskiy <yur@virtuozzo.com>  7.6-14
- Fixed race in guest-exec-finished and exec channels processing #PSBM-75671

* Tue Oct 31 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 7.6-12
- Adapted prl_backup for Bash3 (Alt Linux), #PSBM-70009

* Tue Oct 24 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 7.6-11
- Return manual restart of QEMU GA in case it is not upgraded, but avoid double restart, #PSBM-75528

* Tue Oct 10 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 7.6-10
- Install VERSION file before packages to fix QEMU GA version report, #PSBM-74590

* Tue Oct 10 2017 Konstantin Volkov <wolf@virtuozzo.com> 7.6-9
- Correct centos 6.x vzballoon_blacklist script, see #PSBM-74549

* Fri Sep 29 2017 Konstantin Volkov <wolf@virtuozzo.com> 7.6-7
- Always drop vzvirtio_balloon blacklist, see #PSBM-70554

* Fri Sep  8 2017 Konstantin Volkov <wolf@virtuozzo.com> 7.6-6
- Fixed wrong bash quoting for debian network scripts #PSBM-71766

* Wed Sep  6 2017 Konstantin Volkov <wolf@virtuozzo.com> 7.6-5
- Conditionally choose route or ip utility #PSBM-69266

* Mon Sep 4 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 7.6-4
- Fixed kernel devel installation on SUSE
- Added support for openSUSE 42.3
- Fixed QEMU-GA installation on Alt Linux 7/8, #PSBM-70009
- Fixed fstrim for Alt Linux 7, #PSBM-70009

* Tue Aug 29 2017 Konstantin Volkov <wolf@virtuozzo.com> 7.6-3
- Fixed flag set when stdout/err channels become closed #PSBM-69826

* Thu Aug 24 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 7.6-1
- Fixed: installer did not always detect another running instance, #PSBM-70553
- Changed versioning scheme to avoid ambiguous numbers between branches

* Fri Aug 18 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 0.10-121
- Added basic support for Alt Linux guests, #PSBM-70009

* Tue Aug 15 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 0.10-120
- Use cron for background installation if 'at' is missing, #PSBM-69949

* Mon Aug 14 2017 Denis Silakov <dsilakov@virtuozzo.com> 0.10-119
- Fix balloon installation on Ubuntu-14 with 4.x kernel, #PSBM-62068

* Thu Aug  3 2017 Konstantin Volkov <wolf@virtuozzo.com> 0.10-115.2
- Stop vzvirtio-balloon usage on >= 4.6 kernels in debian-based distros, see #PSBM-69581

* Mon Jul 31 2017 Konstantin Volkov <wolf@virtuozzo.com> 0.10-115.1
- Fix selinux policy to allow chpasswd accessing lock files unlink, see #PSBM-69453

* Wed Jul 12 2017 Denis Silakov <dsilakov@virtuozzo.com> 0.10-115
- Fix selinux policy to allow chpasswd accessing lock files, #PSBM-66169

* Fri Jun 16 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 0.10-113
- Using multi-platform build tasks for vzvirtio_balloon and dkms, #ID-9044

* Tue Jun 13 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 0.10-112
- Minor logging improvements for installer, #PSBM-67143

* Fri Jun 9 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 0.10-111
- Using 'at now' to avoid systemd timeout and qemu-ga restart consequences, #PSBM-67143

* Fri Jun  9 2017 Denis Silakov <dsilakov@virtuozzo.com> 0.10-110
- Fix rhel release check on centos9, do not fail if we get a non-number
  as release, #PSBM-67031

* Fri Jun 2 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 0.10-109
- Using multi-platform vz-guest-udev build task instead of separate tasks, #ID-9044

* Thu May 25 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 0.10-108
- Using multi-platform prl_nettool build task instead of separate tasks, #ID-9044
- prl_nettool updated to the latest upstream version for all platforms

* Mon May 22 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 0.10-107
- Using multi-platform qemu-ga build task instead of separate tasks, #ID-9044

* Mon May 22 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 0.10-106
- Switched to unified Jenkins builds for qemu-ga, #ID-9044

* Wed May 17 2017 Denis Silakov <dsilakov@virtuozzo.com> 0.10-105
- Do not install vzballoon on CentOS 7.3, remove blacklist
  if it is left from older installations (PSBM-66403)

* Mon May 15 2017 Denis Silakov <dsilakov@virtuozzo.com> 0.10-104
- Do not install vzvirtio_balloon on modern systems, #PSBM-66048

* Fri May 12 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 0.10-102
- Fixed post scripts in SUSE packages, #PSBM-65811

* Thu May  4 2017 Denis Silakov <dsilakov@virtuozzo.com> 0.10-101
- Technical rebuild, #PSBM-65928

* Mon Apr 24 2017 Denis Silakov <dsilakov@virtuozzo.com> 0.10-99
- Force 'apt-get update' before installing anything in Ubuntu, #PSBM-65308

* Fri Apr 21 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 0.10-98
- Fixed: Installer showed "Done!" even when there were errors.
- Improved DEB package matching when searching for installed packages, #PSBM-65075

* Thu Apr 20 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 0.10-97
- Installer returns error code if package installation fails, #PSBM-63091

* Thu Apr 20 2017 Denis Silakov <dsilakov@virtuozzo.com> 0.10-96
- Fixed branding

* Tue Apr 18 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 0.10-95
- Fixed VERSION file path in SUSE guest packages, #PSBM-64655

* Mon Apr 17 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 0.10-94
- Detect locked dpkg DB state and repeat installation, #PSBM-64307

* Mon Mar 27 2017 Denis Silakov <dsilakov@virtuozzo.com> 0.10-93
- Start fstrim timer in systemd-based distros during tools install, see #PSBM-62568

* Mon Mar 20 2017 Konstantin Volkov <wolf@virtuozzo.com> 0.10-92
- Rename instdir, see #PSBM-58317

* Thu Mar 16 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 0.10-91
- Added protection from simultaneous running of several installer instances (CentOS 6)

* Fri Mar 10 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 0.10-89
- Moved installer to background to avoid timeout kill by udev, #PSBM-61960

* Fri Mar 10 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 0.10-88
- Fixed application paths in debian packages, #PSBM-60986
- Added workaround for read-only root in Ubuntu udev namespace, #PSBM-60983

* Tue Feb 28 2017 Denis Silakov <dsilakov@virtuozzo.com> 0.10-87
- Enable fstrim in Linux guests only on first install (PSBM-61242)

* Mon Feb 20 2017 Denis Silakov <dsilakov@virtuozzo.com> 0.10-86
- Enable fstrim in Linux guests (#PSBM-60590)

* Thu Feb 16 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 0.10-85
- Added explicit PATH definition (udev environment does not export it).
- Keep user-mounted guest tools CD, #PSBM-60502

* Thu Feb 9 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 0.10-84
- Restart qemu-ga service after installation to make it report the new version, #PSBM-59985

* Fri Feb 3 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 0.10-83
- Fixed: The VERSION file was not added to the ISO image, #PSBM-59852

* Tue Jan 31 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 0.10-82
- Added VERSION file for overriding GA version reporting, #PSBM-56747

* Mon Jan 16 2017 Denis Silakov <dsilakov@virtuozzo.com> 0.10-81
- Force installation of kernel headers for the running kernel (#PSBM-58552)

* Thu Jan 12 2017 Konstantin Vlasov <konstantin.vlasov@virtuozzo.com> 0.10-80
- Fixed mising install-tools on guest OS, so that udev rule worked, #PSBM-23136

* Mon Dec 05 2016 Denis Silakov <dsilakov@virtuozzo.com> 0.10-79
- Install gdebi-core instead of the whole gdebi for Deb-based systems

* Wed Nov 30 2016 Denis Silakov <dsilakov@virtuozzo.com> 0.10-78
- Fix vzvirtio_bzlloon installation in OpenSUSE 42.2, see #PSBM-56342

* Fri Oct 14 2016 Konstantin Volkov <wolf@virtuozzo.com> 0.10-77
- Clear ip list and set method in one nmcli command #PSBM-53683

* Thu Oct 13 2016 Konstantin Volkov <wolf@virtuozzo.com> 0.10-76
- Set manual method only together with IP(s) set, see #PSBM-53565

* Tue Oct 11 2016 Konstantin Volkov <wolf@virtuozzo.com> 0.10-75
- Force to set connection method prior to IP addresses setup, see #PSBM-53152

* Mon Oct 10 2016 Konstantin Volkov <wolf@virtuozzo.com> - 0.10-74
- Properly handle LVM in attached backups in Ubuntu guests, see #PSBM-53345

* Mon Oct 03 2016 Konstantin Neumoin <kneumoin@virtuozzo.com> - 0.10-73
- fix compilation for centos 7.2, debian-8, ubuntu-14.04

* Thu Sep 29 2016 Konstantin Neumoin <kneumoin@virtuozzo.com> - 0.10-72
- Update balloon size on "probe" #PSBM-52275

* Mon Sep 26 2016 Konstantin Neumoin <kneumoin@virtuozzo.com> - 0.10-71
- fix compilation for debian-8

* Fri Sep 23 2016 Konstantin Neumoin <kneumoin@virtuozzo.com> - 0.10-70
- Balloon driver. Temporary fall back to previous tag #PSBM-52275

* Fri Sep 23 2016 Konstantin Neumoin <kneumoin@virtuozzo.com> - 0.10-69
- Update balloon size on startup #PSBM-52275

* Wed Sep 21 2016 Konstantin Volkov <wolf@virtuozzo.com> - 0.10-68
- Clean native connections before NM setup, restart fixed, see #PSBM-52395

* Mon Sep 19 2016 Konstantin Volkov <wolf@virtuozzo.com> - 0.10-67
- Many bugfixes for Ubuntu 16.04, see #PSBM-52004

* Thu Sep 15 2016 Konstantin Neumoin <kneumoin@virtuozzo.com> 0.10-66
- fix compilation for vz7 #PSBM-51658

* Fri Aug 19 2016 Denis Silakov <dsilakov@virtuozzo.com> 0.10-65
- Unify Jenkins job names for dkms

* Thu Aug 18 2016 Konstantin Volkov <wolf@virtuozzo.com> - 0.10-64
- Technical rebuild, see #PSBM-51127

* Wed Aug 17 2016 Konstantin Volkov <wolf@virtuozzo.com> - 0.10-63
- Ignore EBUSY for fsfreeze call #PSBM-50465
- Return statvfs() fsinfo on posix - #PSBM-43139
- Dont return error if cant parse slave virtual device link - #PSBM-43139

* Wed Aug 17 2016 Konstantin Neumoin <kneumoin@virtuozzo.com> 0.10-62
- Fix deflate_on_oom feature in for centos 6.7, debian 7 #PSBM-49967

* Thu Jul 21 2016 Konstantin Neumoin <kneumoin@virtuozzo.com> 0.10-61
- fix infinite loop in virtio balloon on oom notification #PSBM-49193

* Wed Jul 13 2016 Konstantin Neumoin <kneumoin@virtuozzo.com> 0.10-60
- Fix kernel crash on oom notification #PSBM-49176

* Fri Jul  1 2016 Denis Silakov <dsilakov@virtuozzo.com> 0.10-59
- Fix tools update when launched through 'prlctl enter', see #PSBM-49216

* Wed Jun 29 2016 Konstantin Neumoin <kneumoin@virtuozzo.com> 0.10-58
- add workaround for compilation for ubuntu kernels with different
  mm interface.

* Tue Jun 28 2016 Yuriy Pudgorodskiy <yur@virtuozzo.com> - 0.10-57
- Disable cloud-init network config #PSBM-48878
- fix compatibility with new kernel in ubuntu 14.04 #PSBM-49071
  (Konstantin Neumoin <kneumoin@virtuozzo.com>)

* Tue Jun 28 2016 Konstantin Volkov <wolf@virtuozzo.com> - 0.10-56
- If NetworkManager is offline, try to wait for it and re-run nmcli, #PSBM-48372

* Fri Jun 24 2016 Konstantin Volkov <wolf@virtuozzo.com> - 0.10-55
- Added requirement for network.target, see #PSBM-48833

* Thu Jun 23 2016 Konstantin Volkov <wolf@virtuozzo.com> - 0.10-54
- Add check on DHCPv4 to redhat set ip script. #PSBM-48525
- Fix wait of DHCP for some cases. #PSBM-47938

* Wed Jun 22 2016 Alexander Burluka <aburluka@virtuozzo.com> - 0.10-53
- Fixed script that performs ejection to workaround cloud-init
  bad quoting.

* Wed Jun 22 2016 Konstantin Volkov <wolf@virtuozzo.com> 0.10-52
- Didn't set up a method in set IP "remove". #PSBM-48555

* Thu Jun 16 2016 Konstantin Volkov <wolf@virtuozzo.com> 0.10-51
- Add restart for separate interface to debian scripts. #PSBM-24502
- Clear old NM config if network interface were recreated. #PSBM-48328
- Remove service which re-allows NetworkManager read ifcfg-*, #PSBM-48444

* Thu Jun 16 2016 Konstantin Neumoin <kneumoin@virtuozzo.com> 0.10-50
- fix mem_avail id in balloon driver PSBM-48422

* Wed Jun 15 2016 Konstantin Neumoin <kneumoin@virtuozzo.com> 0.10-49
- fix raise in leak/release balloon PSBM-48299

* Tue Jun 14 2016 Konstantin Volkov <wolf@virtuozzo.com> 0.10-48
- Fix ip=remove parsing for NetworkManager, #PSBM-48155
- Run ipconfig /renew to refresh dns search list #PSBM-48116

* Fri Jun 10 2016 Denis Silakov <dsilakov@virtuozzo.com> 0.10-47
- Fix dkms installation in Debian-based systems, see #PSBM-48189

* Wed Jun  8 2016 Konstantin Volkov <wolf@virtuozzo.com> 0.10-46
- Fix get suse config name #PSBM-47906

* Tue Jun  7 2016 Konstantin Volkov <wolf@virtuozzo.com> 0.10-45
- Fix clean IP and GW for iface configured by DHCP #PSBM-47770

* Sat Jun 04 2016 Denis Silakov <dsilakov@virtuozzo.com> 0.10-44
- Build CentOS packages on Jenkins, see #VZP-187

* Fri Jun 03 2016 Denis Silakov <dsilakov@virtuozzo.com> 0.10-43
- Distinguish vz-guest-udev for SUSE and CentOS, see #PSBM-47918
- Fix dkms package for CentOS 7, see #PSBM-47780

* Wed Jun 01 2016 Denis Silakov <dsilakov@virtuozzo.com> 0.10-42
- Fixed prerm scripts in vzvirtio_balloon for debian #PSBM-43057

* Tue May 31 2016 Yuriy Pudgorodskiy <yur@virtuozzo.com> - 0.10-41
- Fixed debian installation #PSBM-47778
- Push installer output to syslogger
- Install gdebi before using it

* Sat May 28 2016 Denis Silakov <dsilakov@virtuozzo.com> 0.10-39
- Build dkms package itself via Jenkins tasks

* Fri May 27 2016 Konstantin Volkov <wolf@virtuozzo.com> - 0.10-38
- Moved VSS registration out of installer scope into agent #PSBM-47558

* Fri May 27 2016 Denis Silakov <dsilakov@virtuozzo.com> 0.10-37
- Automatically build vzvirtio_balloon via Jenkins tasks

* Tue May 24 2016 Denis Silakov <dsilakov@virtuozzo.com> 0.10-36
- Fix requirements for dkms package in Ubuntu 15.10 and 16.04
- Drop kernel config adjustments for vzvirtio_bzlloon build,
  modern vzvirtio sources can be built without it (#PSBM-47480,
  #PSBM-47477).

* Mon May 23 2016 Konstantin Volkov <wolf@virtuozzo.com> - 0.10-35
- Implemented guest-exec-terminate #PSBM-45383
- Added win32 event logging to qemu-ga.exe
- Translate glib log levels to system levels (syslog or windows event)
- Added custom syslog level mask

* Mon May 23 2016 Denis Silakov <dsilakov@virtuozzo.com> 0.10-34
- Added service for Debian-based systems to automatically unbind
  virtio devices from virtio_balloon embedded into kernel
  (#PSBM-43057)

* Mon May 23 2016 Denis Silakov <dsilakov@virtuozzo.com> 0.10-33
- Turn back check for /sbin/init in RHEL-based systems as fallback,
  since CentOS 6.x & co. don't have /etc/os-release (#PSBM-47395)
- Actually add prl_backup to iso.

* Fri May 20 2016 Denis Silakov <dsilakov@virtuozzo.com> 0.10-32
- Added vzvirtio_balloon for Ubuntu 15.10. Added preparation
  step for systems that have virtio_balloon built into kernel.
  #PSBM-43057

* Fri May 20 2016 Igor Bazhitov <ibazhitov@virtuozzo.com> 0.10-31
- Add prl_backup utility to the toolkit. #PSBM-44137

* Sat May 14 2016 Denis Silakov <dsilakov@virtuozzo.com> 0.10-30
- Added vzvirtio_balloon driver. #PSBM-43057

* Wed Apr 27 2016 Denis Silakov <dsilakov@virtuozzo.com> 0.10-29
- Added OpenSUSE Leap support. #PSBM-45502

* Tue Apr 19 2016 Konstantin Volkov <wolf@virtuozzo.com> 0.10-28
- Remove unnecessary call of nmcli see up in check and create
  NM config function. #PSBM-45836

* Tue Apr 12 2016 Konstantin Volkov <wolf@virtuozzo.com> 0.10-27
- fix create_nm_if_config logic

* Wed Mar 30 2016 Konstantin Volkov <wolf@virtuozzo.com> - 0.10-26
- Fixed a number of errors triggered by guest process termination before
  all stdin data sinked, #PSBM-45094
- generic code cleanup and small bugfixes. For #PSBM-43913 and #PSBM-44768

* Wed Mar 16 2016 Alexander Pisarev <apisarev@virtuozzo.com> - 0.10-25
- Fix IPv6 set and DHCP IP change on config change in NM. #PSBM-45066

* Fri Mar  4 2016 Konstantin Volkov <wolf@virtuozzo.com> - 0.10-24
- Fixed dup message from  bad code in flush of aux channel, see #PSBM-44768

* Tue Mar 1 2016 Alexander Burluka <aburluka@virtuozzo.com> - 0.10-23
- Fix escaping in eject command

* Fri Feb 26 2016 Alexander Pisarev <apisarev@virtuozzo.com> - 0.10-22
- Fix sequence of service start. #PSBM-44553

* Tue Feb 23 2016 Konstantin Volkov <wolf@virtuozzo.com> - 0.10-21
- Fix lost of default interface configuration in NM, see #PSBM-44508

* Mon Feb 22 2016 Alexander Burluka <aburluka@virtuozzo.com> - 0.10-20
- Fix eject command

* Mon Feb 22 2016 Maxim Perevedentsev <mperevedentsev@virtuozzo.com> 0.10-19
- Add nameservers/searchdomains to dhclient.conf, #PSBM-43663

* Fri Feb 19 2016 Alexander <apisarev@vitruozzo.com> 0.10-17
- Fixed ip set for VM with NM on interface with method link-local #PSBM-44221

* Thu Feb 18 2016 Alexander Pisarev <apisarev@virtuozzo.com> 0.10-16
- Add separate prl_nettool for RedHat 6 - #PSBM-44221

* Wed Feb 17 2016 Konstantin Volkov <wolf@virtuozzo.com> - 0.10-15
- Updated Linux guest exec shell quoting rules - #PSBM-44045

* Sat Feb 13 2016 Alexander Burluka <aburluka@virtuozzo.com> - 0.10-13
- Fixed mistype in write_files section in vz-lin-user-config

* Wed Feb 10 2016 Alexander Burluka <aburluka@virtuozzo.com> - 0.10-12
- Change vz-lin-user-config format from yaml to json. For #PSBM-41445

* Tue Feb  9 2016 Konstantin Volkov <wolf@virtuozzo.com> - 0.10-11
- Fixed memleak of aux output channels used with sync write codepath.
  Issue #PSBM-43996

* Sat Feb  6 2016 Konstantin Volkov <wolf@virtuozzo.com> - 0.10-10
- Preliminary support for interactive shell. For #PSBM-40821

* Thu Feb  4 2016 Konstantin Volkov <wolf@virtuozzo.com> - 0.10-9
- Fixed default aux channel path not set if main channel path was
  specificed from command line, see #PSBM-40821
- Use signed guest rpms, see #PSBM-43822

* Wed Feb  3 2016 Konstantin Volkov <wolf@virtuozzo.com> - 0.10-8
- Seekable chr dev glib workaround, see #PSBM-40821

* Fri Jan 29 2016 Konstantin <wolf@parallels.com> 0.10-6
- Fix network/interfaces on debians, see #PSBM-43580

* Sat Jan 23 2016 Konstantin <wolf@parallels.com> 0.10-5
- Fix IP receives from dhcp on a Debian VM with tools, see #PSBM-39227

* Fri Jan 22 2016 Konstantin <wolf@parallels.com> 0.10-4
- Fix dhcp after guest tools installed on Debian, see #PSBM-39227

* Fri Jan 22 2016 Konstantin <wolf@parallels.com> 0.10-3
- Do not disable network manager starting from CentOS 7 #PSBM-43173

* Thu Dec 31 2015 Konstantin Volckov <wolf@odin.com> 0.10-2
- Use new-style udev rule, see #PSBM-42894

* Wed Dec 30 2015 Konstantin Volkov <wolf@virtuozzo.com> - 0.10-1
- Quote shell args for execute-in-shell on linux (#PSBM-42726)

* Mon Dec 28 2015 Konstantin Volkov <wolf@virtuozzo.com> - 0.9-1
- Change label name, see #PSBM-41445
- Place Cloud Init data as separate file, see #PSBM-41445

* Wed Dec 23 2015 Konstantin <wolf@parallels.com> 0.8-3
- Renamed qga service, see #PSBM-42627

* Wed Dec 23 2015 Konstantin <wolf@parallels.com> 0.8-2
- Added vz-guest-udev for rpm-based distros, see #PSBM-42574

* Wed Dec 23 2015 Konstantin <wolf@parallels.com> 0.8-1
- Fixed debs prl_nettool scripts path, see #PSBM-42531
- Rename debs qga service to qemu-guest-agent, see #PSBM-42587
- Install required guest udev rules, see #PSBM-42247

* Wed Dec  9 2015 Konstantin <wolf@parallels.com> 0.7-3
- Fixed secondary IPv4 addresses removal on switch to DHCP #PSBM-42096

* Tue Dec  8 2015 Konstantin Volkov <wolf@odin.com> - 0.7-2
- Filled [Install] section, see #PSBM-42105

* Mon Dec  7 2015 Konstantin Volkov <wolf@odin.com> - 0.7-1
- Limited guest-exec stdout/stderr data to maximum supported by
  libvirt xdr rpc for #PSBM-42041

* Fri Dec  4 2015 Konstantin Volkov <wolf@odin.com> - 0.6-1
- Change systemd service requires, see #PSBM-41913

* Fri Dec  4 2015 Konstantin Volkov <wolf@odin.com> - 0.5-1
- guest-set-user-password - added ability to create new user, see #PSBM-41708

* Thu Dec  3 2015 Konstantin Volkov <wolf@odin.com> - 0.4-4
- Update udev rules and reload systemd daemon at the end of installation, see #PSBM-41913

* Tue Dec  1 2015 Konstantin Volkov <wolf@odin.com> - 0.4-3
- Recompiled qga with --disable-pie, see #PSBM-41718
- Implemented new optional bool parameter, 'execute-in-shell'

* Fri Nov 27 2015 Konstantin Volkov <wolf@odin.com> - 0.4-1
- Detect machine arch (for Debian)

* Fri Nov 27 2015 Konstantin Volkov <wolf@odin.com> - 0.4-1
- Added Ubuntu 14.04 and Debian 8 support, see #PSBM-27597

* Thu Nov 26 2015 Konstantin Volkov <wolf@odin.com> - 0.3-4
- Set permissive domain, see #PSBM-41596

* Fri Nov 20 2015 Konstantin Volkov <wolf@odin.com> - 0.3-3
- Added prl_nettool selinux support

* Thu Nov 19 2015 Konstantin Volckov <wolf@odin.com> 0.3-2
- Added selinux support

* Wed Nov 18 2015 Konstantin Volckov <wolf@odin.com> 0.3-1
- Added el6 support

* Thu Nov 12 2015 Konstantin Volckov <wolf@odin.com> 0.2-4
- qga post-un script: enable restart

* Thu Nov 12 2015 Konstantin Volckov <wolf@odin.com> 0.2-3
- Allow update already existing rpms

* Thu Nov 12 2015 Konstantin Volckov <wolf@odin.com> 0.2-2
- qga bump

* Mon Nov  9 2015 Konstantin Volckov <wolf@odin.com> 0.2-1
- Added prl_nettool

* Thu Nov  5 2015 Konstantin Volckov <wolf@odin.com> 0.1-1
- Initial release
